@@ -4,9 +4,10 @@
 Module for taking DataLab screenshots
 """
 
-from cdl import config
-from cdl.tests.features.applauncher import launcher1_app_test
-from cdl.tests.scenarios import beautiful_app
+from datalab import config
+from datalab.tests.features.applauncher import launcher1_app_test
+from datalab.tests.features.utilities import settings_unit_test
+from datalab.tests.scenarios import beautiful_app
 
 if __name__ == "__main__":
     print("Updating screenshots...", end=" ")
@@ -14,4 +15,6 @@ if __name__ == "__main__":
     launcher1_app_test.test_launcher1(screenshots=True)
     config.reset()
     beautiful_app.run_beautiful_scenario(screenshots=True)
+    beautiful_app.run_blob_detection_on_flower_image(screenshots=True)
+    settings_unit_test.capture_settings_screenshots()
     print("done.")
