@@ -4,11 +4,11 @@ import numpy as np
 import scipy.ndimage as spi
 
 # When using this code outside of DataLab (which is possible!), you may use the
-# *Simple DataLab Client* (see https://pypi.org/project/cdlclient/), installed with
-# `pip install cdlclient`), as it's more lightweight than the full DataLab package:
+# client provided by the `Sigima` package (see https://pypi.org/project/sigima/),
+# installed with `pip install sigima`, for example, instead of the full DataLab package:
 #
-# from cdlclient import SimpleRemoteProxy as RemoteProxy
-from cdl.proxy import RemoteProxy
+# from sigima.client import SimpleRemoteProxy as RemoteProxy
+from datalab.control.proxy import RemoteProxy
 
 proxy = RemoteProxy()
 proxy.set_current_panel("image")
